#ifndef __RUTE_H
#define __RUTE_H

#include <algorithm>
#include <iomanip>
#include <iostream>
#include <list>

#include "enumer.h"
#include "hjelpeFunksjoner.h"
#include "konstanter.h"
#include "lesData3.h"
#include "stoppested.h"
#include "stoppesteder.h"

/**
 * Stopp struct, holder data for et stopp
 * med vector indeksen til stoppestedet og
 * minutter mellom forrige stoppested.
 *
 */
struct Stopp {
    int indexStoppested;
    int minutterFraForrigeStoppested;
};

/**
 * Baseklassen Rute.
 * Har datamedlemmet:
 *      alleStoppestedenePaaRuten - Liste over pekere til stopp structer.
 *
 */
class Rute {
   private:
    HjelpeFunksjoner hjelp;

   public:
    // Liste over pekere til stopp structer.
    std::list<Stopp*> alleStoppestedenePaaRuten;
    Rute();
    virtual ~Rute();
    Stopp* ny(const int& eksisterende, int pos);
    void ryddOppMinne();
    void skrivData();
    virtual void skrivDataForlengs();
    virtual void skrivDataBaklengs();
    bool sjekkOmStoppEksisterer(Stopp* stopp);
    void endre();
    void slettStoppested(const int& start, const int& slutt);
    void smettInnStoppested(const int& start, const int& slutt);
    void leggTilStoppestedIRute(Stopp* stopp);
    void oppdaterStoppestedVectorer(Stoppested* stoppested,
                                    Stoppested* forrigeStoppested,
                                    Stopp* stopp,
                                    Stopp* forrigeStopp);
    int lesTid();
    virtual void skrivType();
    void tabell();
    int hentTotalTidForan(const int& navn);
    int hentTotalTidTilbake(const int& navn);
    virtual void lesFraFil(std::ifstream& inn);
    virtual void skrivTilFil(std::ofstream& ut);
};

#endif  //__RUTE_H